"""URLs to run the tests."""
from django.conf.urls import patterns, include, url
from django.contrib import admin

from sessioninfo.tests.test_app.views import get_session_user_view

admin.autodiscover()

urlpatterns = patterns(
    '',
    url(r'^admin/', include(admin.site.urls)),
    url(r'^get-session-user/', get_session_user_view),
)


# -*- coding: utf-8 -*-

try:
    from django.apps import AppConfig
except ImportError:
    pass  # Django < 1.7
else:

    class Config(AppConfig):
        name = 'sessioninfo'
        verbose_name = ''


# -*- coding: utf-8 -*-
from django.contrib.sessions.models import Session
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = 'Kill/delete all sessions, log out all users.'

    def handle(self, *args, **options):
        Session.objects.all().delete()



#from django.contrib.auth.decorators import login_required
#from django.shortcuts import render_to_response
#from django.shortcuts import get_object_or_404
#from django.template import RequestContext
#from django.shortcuts import redirect
#from django.template.defaultfilters import slugify
#from django.core.urlresolvers import reverse
#from django.http import Http404
#from django.http import HttpResponseForbidden
#from django.http import HttpResponseServerError
#from django.http import HttpResponseRedirect

# class YourView(TemplateView):
#    template_name = 'sessioninfo/default.html'


from django.contrib.sessions.models import Session
from compat import get_user_model

def get_session_user(request):
    '''
    Extracts user from POST request.
    Returns None if there is no session or method is not POST
    '''
    if request.method == 'POST' and 'session_key' in request.POST:
        try:
            session_key = request.POST['session_key']
            session = Session.objects.get(session_key=session_key)
            uid = session.get_decoded().get('_auth_user_id')
            return get_user_model().objects.get(pk=uid)
        except Session.DoesNotExist:
            pass
    return None


# -*- coding: utf-8 -*-

"""Models for the sessioninfo app."""

# from django.db import models
# from django.utils.translation import ugettext_lazy as _
# from django.utils.encoding import python_2_unicode_compatible


"""
@python_2_unicode_compatible
class Item(models.Model):
    name = models.CharField(max_length=100)
    items = models.ManyToManyField('self', blank=True)
    private = models.BooleanField(default=True)

    class Meta:
        verbose_name = 'Item'
        verbose_name_plural = 'Items'

    def __str__(self):
        return self.name
"""


"""Tests for the models of the sessioninfo app."""
from django.contrib.auth.models import User
from django.test import TestCase, Client

class SessionInfoTests(TestCase):

    def setUp(self):
        self.user_username = 'user'
        self.user_email = 'user@example.com'
        self.user_password = 'user_pw'
        self.user = User.objects.create_user(self.user_username, self.user_email, self.user_password)

        self.client = Client()
        self.client.login(username=self.user_username, password=self.user_password)

    def test_get_session_user(self):
        s = self.client.session
        s.save()
        session_key = s.session_key
        response = self.client.post('/get-session-user/', {'session_key': session_key})
        self.assertEqual(response.status_code, 200)
        self.assertEqual(int(response.content), self.user.id)


# -*- coding: utf-8 -*-
from django.conf import settings
from django.contrib import admin
from django.contrib.sessions.models import Session


class SessionAdmin(admin.ModelAdmin):
    def _session_data(self, obj):
        return obj.get_decoded()

    list_display = ['session_key', '_session_data', 'expire_date']


show_sessions = getattr(settings, 'SHOW_SESSIONS_IN_ADMIN', False)
if show_sessions:
    admin.site.register(Session, SessionAdmin)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys

import sessioninfo

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

version = sessioninfo.__version__

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    print("You probably want to also tag the version now:")
    print("  git tag -a %s -m 'version %s'" % (version, version))
    print("  git push --tags")
    sys.exit()

readme = open('README.md').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')
classifiers = [c for c in open('classifiers').read().splitlines() if '#' not in c]

setup(
    name='django-sessioninfo',
    version=version,
    description="""Your project description goes here""",
    long_description=readme + '\n\n' + history,
    author='arteria GmbH',
    author_email='admin@arteria.ch',
    url='https://github.com/arteria/django-sessioninfo',
    packages=[
        'sessioninfo',
    ],
    include_package_data=True,
    install_requires=open('requirements.txt').read().splitlines(),
    license="BSD",
    zip_safe=False,
    keywords='django-sessioninfo',
    classifiers=classifiers,
)


"""URLs for the sessioninfo app."""

# from django.conf.urls import patterns, url

# from sessioninfo import views


# urlpatterns = patterns(
#     '',
#     url(r'^$',
#         views.YourView.as_view(),
#         name='sessioninfo_default'),
# )